USE TFC
GO

CREATE TABLE Departamento
	(Cod_dep	int PRIMARY KEY NOT NULL,
	Nombre_dep	varchar(30) NOT NULL,
	);
	
CREATE TABLE Proyecto
	(Cod_proyecto	int PRIMARY KEY NOT NULL,
	Nombre_proyecto	varchar(30) NOT NULL,
	Cod_dep			int NOT NULL,
	Fecha_inicio	date,
	Fecha_fin		date,
	Estado			varchar (20),
	);
	
	
CREATE TABLE Empleado
	(Cod_emp	int PRIMARY KEY NOT NULL,
	Nombre		varchar(50) NOT NULL,
	Oficina		varchar(10),
	Telefono	int,
	Cod_dept	int NOT NULL,
	Password	varchar(30),
	);


CREATE TABLE EmpleadoProyecto
	(Cod_emp		int NOT NULL,
	Cod_proyecto	int  NOT NULL,
	Horas			int,
	primary Key (Cod_emp,Cod_proyecto),
	CONSTRAINT FK_proyecto_empleado FOREIGN KEY (cod_proyecto)
		REFERENCES Proyecto (cod_proyecto)
		ON DELETE CASCADE,
	CONSTRAINT FK_empleado_proyecto FOREIGN KEY (Cod_emp)
		REFERENCES Empleado (Cod_emp)
		ON DELETE CASCADE
		ON UPDATE CASCADE
	);

CREATE TABLE JefeProyecto
	(Cod_emp		int PRIMARY KEY NOT NULL,
	Cod_proyecto	int NOT NULL,
	fecha_inicio	date NOT NULL,
	CONSTRAINT FK_jefe_proyecto FOREIGN KEY (cod_proyecto)
		REFERENCES Proyecto (cod_proyecto)
		ON DELETE CASCADE,
	CONSTRAINT FK_jefe_empleado_proyecto FOREIGN KEY (Cod_emp)
		REFERENCES Empleado (Cod_emp)
		ON DELETE CASCADE
		ON UPDATE CASCADE
	);	
	
CREATE TABLE JefeDepartamento
	(Cod_emp		int PRIMARY KEY NOT NULL,
	Cod_dept		int NOT NULL,
	fecha_inicio	date NOT NULL,
	CONSTRAINT FK_jefe_departamento FOREIGN KEY (Cod_dept)
		REFERENCES Departamento (Cod_dep)
		ON DELETE CASCADE,
	CONSTRAINT FK_jefe_empleado_departamento FOREIGN KEY (Cod_emp)
		REFERENCES Empleado (Cod_emp)
		ON DELETE CASCADE
		ON UPDATE CASCADE
	);	

CREATE TABLE Hoja
	(id_hoja		int IDENTITY(1000,1) PRIMARY KEY NOT NULL ,
	Cod_emp			int NOT NULL,
	Referencia		int NOT NULL,
	Localidad		varchar(20) NOT NULL,
	Motivo			varchar(100),
	Pais			varchar(30) NOT NULL,
	Fecha_origen	date NOT NULL,
	Fecha_destino	date NOT NULL,
	Importe			decimal(6,2) NOT NULL,
	Fecha_creada	date,
	Cod_aprobada	int,
	Fecha_aprobacion	date,
	Cod_autorizada		int,
	Fecha_autorizada	date,
	Estado			varchar (15) NOT NULL,
	Motivo_rechazo	varchar(700),
	CONSTRAINT FK_usuario_hoja FOREIGN KEY (Cod_emp)
		REFERENCES Empleado (Cod_emp)
		ON DELETE CASCADE
		ON UPDATE CASCADE,
	CONSTRAINT FK_hoja_jefe_autoriza FOREIGN KEY (Cod_autorizada)
		REFERENCES JefeDepartamento (Cod_emp)
	
	);	

CREATE TABLE Hoja_Adjunto
	(id_hoja 		int PRIMARY KEY NOT NULL,
	archivo			VARBINARY(MAX),
	CONSTRAINT FK_hoja_archivo_adjunto FOREIGN KEY (id_hoja)
		REFERENCES HOJA (id_hoja) ON DELETE CASCADE
	);
	
	
CREATE TABLE Tipos_gasto
	(Cod_gasto		varchar(3) PRIMARY KEY NOT NULL,
	Denominacion	varchar(30),
	Descripcion		varchar(70),
	Valor			decimal(5,2),
	);
	
CREATE TABLE Gasto
	(id_gasto		int IDENTITY(200,1) PRIMARY KEY NOT NULL,
	Cod_hoja		int NOT NULL,
	Pais			varchar(30) NOT NULL,
	Concepto		varchar(3) NOT NULL,
	Unidades		int NOT NULL,
	Importe			decimal(6,2) NOT NULL,
	Total			decimal(6,2) NOT NULL,
	Fecha			date,
	CONSTRAINT FK_gasto_hoja FOREIGN KEY (Cod_hoja)
		REFERENCES Hoja (id_hoja)
		ON DELETE CASCADE
		ON UPDATE CASCADE,
	CONSTRAINT fk_tipogasto_gasto FOREIGN KEY (concepto)
		REFERENCES Tipos_gasto (cod_gasto)
		ON UPDATE CASCADE,
	);	
	

	
CREATE TABLE Festivos 
(		fecha	date PRIMARY KEY NOT NULL,
);

-- Insertar en la tabla Festivos
INSERT INTO Festivos VALUES ('01/01/2013');
INSERT INTO Festivos VALUES ('07/01/2013');
INSERT INTO Festivos VALUES ('18/03/2013');
INSERT INTO Festivos VALUES ('28/03/2013');
INSERT INTO Festivos VALUES ('29/03/2013');
INSERT INTO Festivos VALUES ('01/05/2013');
INSERT INTO Festivos VALUES ('15/08/2013');
INSERT INTO Festivos VALUES ('12/10/2013');
INSERT INTO Festivos VALUES ('01/11/2013');
INSERT INTO Festivos VALUES ('06/12/2013');
INSERT INTO Festivos VALUES ('25/12/2013');
INSERT INTO Festivos VALUES ('10/12/2013');
INSERT INTO Festivos VALUES ('14/12/2013');
	


-- Insertar en la tabla tipos_gasto
INSERT INTO Tipos_gasto VALUES ('CAT','Atenciones','Atenciones a clientes',0)
INSERT INTO Tipos_gasto VALUES ('C1P','Comida una persona','Desayuno, comida, merienda, cena personal',0)
INSERT INTO Tipos_gasto VALUES ('DCO','Dieta de comida','Dieta por día sin cambio de domicilio',20)
INSERT INTO Tipos_gasto VALUES ('DID','Dieta completa','Dieta por desplazamiento día completo',80.30)
INSERT INTO Tipos_gasto VALUES ('DIM','Dietas medias','Medias dietas por desplazamiento',40.15)
INSERT INTO Tipos_gasto VALUES ('FYE','Feries y exposiciones','Gastos en ferias y exposiciones',0)
INSERT INTO Tipos_gasto VALUES ('FOT','Fotografias','Compra de fotografias',0)
INSERT INTO Tipos_gasto VALUES ('GAP','Gastos aparcamiento','Gastos pagados por el empleado en aparcamiento',0)
INSERT INTO Tipos_gasto VALUES ('GAU','Gastos autopista','Gastos pagados por el empleado en autopistas',0)
INSERT INTO Tipos_gasto VALUES ('GGA','Gastos gasolina','Gastos pagados por el empleado en gasolina',0)
INSERT INTO Tipos_gasto VALUES ('GTP','Gastos transporte publico','Gastos pagados en transporte publico',0)
INSERT INTO Tipos_gasto VALUES ('GVA','Gastos varios','Gastos variados',0)
INSERT INTO Tipos_gasto VALUES ('GVM','Gastos varios manutencion','Gastos pequeños ocasionados en hosteleria',0)
INSERT INTO Tipos_gasto VALUES ('HTL','Hoteles','Gastos en hoteles pagados por el empleado',0)
INSERT INTO Tipos_gasto VALUES ('KM','Kilometros','Kilometros en coche propio',0.40)
INSERT INTO Tipos_gasto VALUES ('TFN','Teléfono','Gastos en telefono particular',0)




-- Inserciones en la tabla Departamento
INSERT Departamento (Cod_dep, Nombre_dep) VALUES (110, 'Departamento NAVAL');
INSERT Departamento (Cod_dep, Nombre_dep) VALUES (210, 'Departamento FINANCIERO');
INSERT Departamento (Cod_dep, Nombre_dep) VALUES (230, 'Departamento CONTROL');
INSERT Departamento (Cod_dep, Nombre_dep) VALUES (310, 'Departamento CIVIL');
INSERT Departamento (Cod_dep, Nombre_dep) VALUES (320, 'Departamento INDUSTRIAL');
INSERT Departamento (Cod_dep, Nombre_dep) VALUES (330, 'Departamento MECANICA');
 
-- Inserciones en la tabla Proyecto
INSERT Proyecto (Cod_proyecto, Nombre_proyecto,Fecha_inicio,Fecha_fin,Estado,Cod_dep) 
	VALUES (12232, 'Proyecto Refinacion buqueXTP','20/05/2010','20/05/2011', 'Cerrado', 110);
INSERT Proyecto (Cod_proyecto, Nombre_proyecto,Fecha_inicio,Fecha_fin,Estado,Cod_dep) 
	VALUES (12235, 'Proyecto Refinacion buqueNOR','15/01/2012','23/05/2013', 'Cerrado', 110);	
INSERT Proyecto (Cod_proyecto, Nombre_proyecto,Fecha_inicio,Estado,Cod_dep) 
	VALUES (12239, 'Proyecto Refinacion buqueNOR','15/06/2013','Abierto', 110);
	
INSERT Proyecto (Cod_proyecto, Nombre_proyecto,Fecha_inicio,Fecha_fin,Estado,Cod_dep) 
	VALUES (31314, 'Proyecto TREN MARTE','04/03/2012','18/07/2013', 'Cerrado', 310);
INSERT Proyecto (Cod_proyecto, Nombre_proyecto,Fecha_inicio,Fecha_fin,Estado,Cod_dep) 
	VALUES (31111, 'Proyecto TREN SATURNO','04/03/2011','18/07/2013', 'Cerrado', 310);
INSERT Proyecto (Cod_proyecto, Nombre_proyecto,Fecha_inicio,Estado,Cod_dep) 
	VALUES (31445, 'Proyecto ACUEDUCTO TOR','15/08/2013','Abierto', 310);	

INSERT Proyecto (Cod_proyecto, Nombre_proyecto,Fecha_inicio,Fecha_fin,Estado,Cod_dep) 
	VALUES (32154, 'Proyecto CASTOR','04/03/2010','18/07/2012', 'Cerrado', 320);
INSERT Proyecto (Cod_proyecto, Nombre_proyecto,Fecha_inicio,Fecha_fin,Estado,Cod_dep) 
	VALUES (32611, 'Proyecto MOVITORN','21/12/2012','18/07/2013', 'Cerrado', 320);
INSERT Proyecto (Cod_proyecto, Nombre_proyecto,Fecha_inicio,Estado,Cod_dep) 
	VALUES (32945, 'Proyecto MANTER','28/04/2013','Abierto', 320);	
	
INSERT Proyecto (Cod_proyecto, Nombre_proyecto,Fecha_inicio,Fecha_fin,Estado,Cod_dep) 
	VALUES (33121, 'Proyecto CASTOR','12/12/2010','18/02/2012', 'Cerrado', 330);
INSERT Proyecto (Cod_proyecto, Nombre_proyecto,Fecha_inicio,Fecha_fin,Estado,Cod_dep) 
	VALUES (33375, 'Proyecto MOVITORN','29/05/2012','14/01/2013', 'Cerrado', 330);
INSERT Proyecto (Cod_proyecto, Nombre_proyecto,Fecha_inicio,Estado,Cod_dep) 
	VALUES (33645, 'Proyecto ACUEDUCTO TOR','12/02/2013','Abierto', 330);		

	
	
-- Inserciones en la tabla Empleado 
INSERT Empleado (Cod_emp, Nombre,Oficina,Telefono,Cod_dept,password) 
	VALUES (2410,'Martinez Rodriguez, Alfredo','Madrid',685215021,110,'2410');
INSERT Empleado (Cod_emp, Nombre,Oficina,Telefono,Cod_dept,password) 
	VALUES (2631,'Lopez Manto, Marta','Madrid',61221221,110,'2631');
INSERT Empleado (Cod_emp, Nombre,Oficina,Telefono,Cod_dept,password) 
	VALUES (2314,'Gomez Tomar, Luis','Madrid',698654257,110,'2314');	
INSERT Empleado (Cod_emp, Nombre,Oficina,Telefono,Cod_dept,password) 
	VALUES (2515,'Gomez Gomar, Raquel','Barcelona',658236102,110,'2515');
INSERT Empleado (Cod_emp, Nombre,Oficina,Telefono,Cod_dept,password) 
	VALUES (2562,'Martinez Puig, David','Barcelona',620124591,110,'2562');
INSERT Empleado (Cod_emp, Nombre,Oficina,Telefono,Cod_dept,password) 
	VALUES (2414,'Floro Jimenez, Javier','Madrid',620454591,110,'2414');

INSERT Empleado (Cod_emp, Nombre,Oficina,Telefono,Cod_dept,password) 
	VALUES (2111,'Consuegra Rodriguez, Sara','Madrid',654121987,210,'2111');
INSERT Empleado (Cod_emp, Nombre,Oficina,Telefono,Cod_dept,password) 
	VALUES (2222,'Bernal Fernandez, Ignacio','Madrid',698325100,210,'2222');
INSERT Empleado (Cod_emp, Nombre,Oficina,Telefono,Cod_dept,password) 
	VALUES (2777,'Jimenez Tobias, Ramon','Madrid',610325301,210,'2777');

INSERT Empleado (Cod_emp, Nombre,Oficina,Telefono,Cod_dept,password) 
	VALUES (2333,'Herrero Martinez, Jose Carlos','Madrid',600210025,230,'2333');
INSERT Empleado (Cod_emp, Nombre,Oficina,Telefono,Cod_dept,password) 
	VALUES (2444,'Gomez del Alamo, Patricia','Barcelona',600187745,230,'2444');		
INSERT Empleado (Cod_emp, Nombre,Oficina,Telefono,Cod_dept,password) 
	VALUES (2888,'Cortes, Fernando','Barcelona',644187745,230,'2888');	
	
INSERT Empleado (Cod_emp, Nombre,Oficina,Telefono,Cod_dept,password) 
	VALUES (2123,'Varela Rodriguez, Borja','Madrid',666321121,310,'2123'); 
INSERT Empleado (Cod_emp, Nombre,Oficina,Telefono,Cod_dept,password) 
	VALUES (2351,'Rivera Feliz, Alvaro','Madrid',636540251,310,'2351');
INSERT Empleado (Cod_emp, Nombre,Oficina,Telefono,Cod_dept,password) 
	VALUES (2369,'Martinez Gomez, Javier','Valencia',698896222,310,'2369');	
INSERT Empleado (Cod_emp, Nombre,Oficina,Telefono,Cod_dept,password) 
	VALUES (2984,'Vazquez Fernandez, Jose Luis','Valencia',662226111,310,'2984');
INSERT Empleado (Cod_emp, Nombre,Oficina,Telefono,Cod_dept,password) 
	VALUES (2740,'Fernandez Fernandez, Antonia','Valencia',633221122,310,'2740');
INSERT Empleado (Cod_emp, Nombre,Oficina,Telefono,Cod_dept,password) 
	VALUES (2665,'Jimenez Berrocal, Marcos','Valencia',633525522,310,'2665');
	
INSERT Empleado (Cod_emp, Nombre,Oficina,Telefono,Cod_dept,password) 
	VALUES (2254,'Roman Rodriguez, Clara','Barcelona',656888888,320,'2254'); 
INSERT Empleado (Cod_emp, Nombre,Oficina,Telefono,Cod_dept,password) 
	VALUES (2421,'del Barrio Marquez, Laura','Barcelona',698544774,320,'2421');
INSERT Empleado (Cod_emp, Nombre,Oficina,Telefono,Cod_dept,password) 
	VALUES (2907,'Fernandez Martin, Sergio','Barcelona',699332211,320,'2907');	
INSERT Empleado (Cod_emp, Nombre,Oficina,Telefono,Cod_dept,password) 
	VALUES (2797,'Villanueva de la Vara, Jose','Barcelona',633000114,320,'2797');
INSERT Empleado (Cod_emp, Nombre,Oficina,Telefono,Cod_dept,password) 
	VALUES (2878,'Sexto Manton, Miguel','Barcelona',697741250,320,'2878');
INSERT Empleado (Cod_emp, Nombre,Oficina,Telefono,Cod_dept,password) 
	VALUES (2688,'Tolmo Lopez, Francisco','Barcelona',693443250,320,'2688');
	
INSERT Empleado (Cod_emp, Nombre,Oficina,Telefono,Cod_dept,password) 
	VALUES (2645,'Martin Varela, Borja','Madrid',625401201,330,'2645'); 
INSERT Empleado (Cod_emp, Nombre,Oficina,Telefono,Cod_dept,password) 
	VALUES (2748,'Martin Saez, Pedro','Madrid',620154871,330,'2748');
INSERT Empleado (Cod_emp, Nombre,Oficina,Telefono,Cod_dept,password) 
	VALUES (2647,'Saez Diaz, Melania','Madrid',654001122,330,'2647');	
INSERT Empleado (Cod_emp, Nombre,Oficina,Telefono,Cod_dept,password) 
	VALUES (2453,'Pedro Rivera, Camilo','Madrid',698989878,330,'2453');
INSERT Empleado (Cod_emp, Nombre,Oficina,Telefono,Cod_dept,password) 
	VALUES (2045,'Sanchez Lopez, Diana','Madrid',678549862,330,'2045');
INSERT Empleado (Cod_emp, Nombre,Oficina,Telefono,Cod_dept,password) 
	VALUES (2058,'Fernandez Rico, Marta','Madrid',676654862,330,'2058');
	

-- Inserciones en la tabla EmpleadoProyecto 
INSERT EmpleadoProyecto (Cod_emp, Cod_proyecto,Horas) VALUES (2410,12232,50);
INSERT EmpleadoProyecto (Cod_emp, Cod_proyecto,Horas) VALUES (2410,12239,12);
INSERT EmpleadoProyecto (Cod_emp, Cod_proyecto,Horas) VALUES (2631,12232,123);
INSERT EmpleadoProyecto (Cod_emp, Cod_proyecto,Horas) VALUES (2631,12235,241);
INSERT EmpleadoProyecto (Cod_emp, Cod_proyecto,Horas) VALUES (2314,12232,123);
INSERT EmpleadoProyecto (Cod_emp, Cod_proyecto,Horas) VALUES (2314,12239,12);
INSERT EmpleadoProyecto (Cod_emp, Cod_proyecto,Horas) VALUES (2515,12239,25);
INSERT EmpleadoProyecto (Cod_emp, Cod_proyecto,Horas) VALUES (2562,12239,66);
INSERT EmpleadoProyecto (Cod_emp, Cod_proyecto,Horas) VALUES (2333,12239,55);
INSERT EmpleadoProyecto (Cod_emp, Cod_proyecto,Horas) VALUES (2333,12235,10);

INSERT EmpleadoProyecto (Cod_emp, Cod_proyecto,Horas) VALUES (2123,31314,110);
INSERT EmpleadoProyecto (Cod_emp, Cod_proyecto,Horas) VALUES (2351,31314,110);
INSERT EmpleadoProyecto (Cod_emp, Cod_proyecto,Horas) VALUES (2369,31314,230);
INSERT EmpleadoProyecto (Cod_emp, Cod_proyecto,Horas) VALUES (2444,31314,10);
INSERT EmpleadoProyecto (Cod_emp, Cod_proyecto,Horas) VALUES (2984,31445,10);
INSERT EmpleadoProyecto (Cod_emp, Cod_proyecto,Horas) VALUES (2740,31445,50);
INSERT EmpleadoProyecto (Cod_emp, Cod_proyecto,Horas) VALUES (2351,31445,230);

INSERT EmpleadoProyecto (Cod_emp, Cod_proyecto,Horas) VALUES (2254,32611,10);
INSERT EmpleadoProyecto (Cod_emp, Cod_proyecto,Horas) VALUES (2421,32611,150);
INSERT EmpleadoProyecto (Cod_emp, Cod_proyecto,Horas) VALUES (2907,32611,12);
INSERT EmpleadoProyecto (Cod_emp, Cod_proyecto,Horas) VALUES (2907,32945,5);
INSERT EmpleadoProyecto (Cod_emp, Cod_proyecto,Horas) VALUES (2254,32945,10);
INSERT EmpleadoProyecto (Cod_emp, Cod_proyecto,Horas) VALUES (2878,32945,41);
INSERT EmpleadoProyecto (Cod_emp, Cod_proyecto,Horas) VALUES (2797,32945,56);

INSERT EmpleadoProyecto (Cod_emp, Cod_proyecto,Horas) VALUES (2645,33375,66);
INSERT EmpleadoProyecto (Cod_emp, Cod_proyecto,Horas) VALUES (2748,33375,35);
INSERT EmpleadoProyecto (Cod_emp, Cod_proyecto,Horas) VALUES (2748,33645,78);
INSERT EmpleadoProyecto (Cod_emp, Cod_proyecto,Horas) VALUES (2647,33645,133);
INSERT EmpleadoProyecto (Cod_emp, Cod_proyecto,Horas) VALUES (2453,33645,13);
INSERT EmpleadoProyecto (Cod_emp, Cod_proyecto,Horas) VALUES (2045,33645,63);
INSERT EmpleadoProyecto (Cod_emp, Cod_proyecto,Horas) VALUES (2444,33645,46);

-- Inserciones en la tabla JefeProyecto   
INSERT JefeProyecto (Cod_emp, Cod_proyecto,fecha_inicio) VALUES (2410,12232,'20/05/2010');
INSERT JefeProyecto (Cod_emp, Cod_proyecto,fecha_inicio) VALUES (2631,12235,'15/01/2012');
INSERT JefeProyecto (Cod_emp, Cod_proyecto,fecha_inicio) VALUES (2314,12239,'15/06/2013');

INSERT JefeProyecto (Cod_emp, Cod_proyecto,fecha_inicio) VALUES (2123,31314,'04/03/2012');
INSERT JefeProyecto (Cod_emp, Cod_proyecto,fecha_inicio) VALUES (2351,31111,'04/03/2011');
INSERT JefeProyecto (Cod_emp, Cod_proyecto,fecha_inicio) VALUES (2740,31445,'15/08/2013');

INSERT JefeProyecto (Cod_emp, Cod_proyecto,fecha_inicio) VALUES (2254,32154,'04/03/2010');
INSERT JefeProyecto (Cod_emp, Cod_proyecto,fecha_inicio) VALUES (2797,32611,'21/12/2012');
INSERT JefeProyecto (Cod_emp, Cod_proyecto,fecha_inicio) VALUES (2421,32945,'28/04/2013');

INSERT JefeProyecto (Cod_emp, Cod_proyecto,fecha_inicio) VALUES (2645,33121,'12/12/2010');
INSERT JefeProyecto (Cod_emp, Cod_proyecto,fecha_inicio) VALUES (2748,33375,'29/05/2012');
INSERT JefeProyecto (Cod_emp, Cod_proyecto,fecha_inicio) VALUES (2647,33645,'12/02/2013');


-- Inserciones en la tabla JefeDepartamento
INSERT JefeDepartamento (Cod_emp, Cod_dept,fecha_inicio) VALUES (2414,110,'23/11/2009');
INSERT JefeDepartamento (Cod_emp, Cod_dept,fecha_inicio) VALUES (2777,210,'10/02/2010');
INSERT JefeDepartamento (Cod_emp, Cod_dept,fecha_inicio) VALUES (2888,230,'18/01/2011');
INSERT JefeDepartamento (Cod_emp, Cod_dept,fecha_inicio) VALUES (2665,310,'15/05/2012');
INSERT JefeDepartamento (Cod_emp, Cod_dept,fecha_inicio) VALUES (2688,320,'21/04/2013');
INSERT JefeDepartamento (Cod_emp, Cod_dept,fecha_inicio) VALUES (2058,330,'05/08/2010');


-- Inserciones en la tabla Hojas

--Jefe de proyecto con dos hojas cerradas. Una a su proyecto otra a su departamento
INSERT Hoja (Cod_emp,Referencia,Localidad,Motivo,Fecha_origen,Fecha_destino,Importe,Pais,Fecha_creada,Cod_aprobada,Fecha_aprobacion,Cod_autorizada,Fecha_autorizada, Estado)
	VALUES (2314,12239,'Madrid','Reunion Proyecto','12/06/2013','15/06/2013',48.15,'España','20/06/2013',2314,'21/06/2013',2414,'22/06/2013','Cerrada');
INSERT Hoja (Cod_emp,Referencia,Localidad,Motivo,Fecha_origen,Fecha_destino,Importe,Pais,Fecha_creada,Cod_aprobada,Fecha_aprobacion,Cod_autorizada,Fecha_autorizada, Estado)
	VALUES (2314,110,'Bilbao','Reunion Proyecto2','01/08/2013','02/08/2013',453.6,'España','05/08/2013',2414,'13/08/2013',2414,'31/08/2013','Cerrada');

-- Jefe de departamento. 1 Hoja cerrada. 1 hoja abierta solicitar pago	
INSERT Hoja (Cod_emp,Referencia,Localidad,Motivo,Fecha_origen,Fecha_destino,Importe,Pais,Fecha_creada,Cod_aprobada,Fecha_aprobacion,Cod_autorizada,Fecha_autorizada, Estado)
	VALUES (2414,110,'Madrid','Reunion presidencial','11/07/2013','12/07/2013',20,'España','28/07/2013',2414,'30/07/2013',2414,'30/07/2013','Cerrada');
INSERT Hoja (Cod_emp,Referencia,Localidad,Motivo,Fecha_origen,Fecha_destino,Importe,Pais,Fecha_creada, Estado)
	VALUES (2414,110,'Madrid','Reunion direccion','04/12/2013','06/12/2013',50.4,'España','10/12/2013','Abierta');
	
-- Usuario normal, 1 hoja cerrada, 1 abierta,  todas a proyecto
INSERT Hoja (Cod_emp,Referencia,Localidad,Motivo,Fecha_origen,Fecha_destino,Importe,Pais,Fecha_creada,Cod_aprobada,Fecha_aprobacion,Cod_autorizada,Fecha_autorizada, Estado)
	VALUES (2333,12239,'Lisboa','Viaje Proyecto','07/10/2013','11/10/2013',188.3,'Portugal','15/10/2013',2314,'24/10/2013',2888,'25/10/2013','Cerrada');
INSERT Hoja (Cod_emp,Referencia,Localidad,Motivo,Fecha_origen,Fecha_destino,Importe,Pais,Fecha_creada,Cod_aprobada,Fecha_aprobacion,Cod_autorizada,Fecha_autorizada, Estado)
	VALUES (2333,12235,'Valencia','TEST','11/10/2013','14/10/2013',80,'España','15/10/2013',2631,'24/10/2013',2888,'25/10/2013','Cerrada');
INSERT Hoja (Cod_emp,Referencia,Localidad,Motivo,Fecha_origen,Fecha_destino,Importe,Pais,Fecha_creada,Cod_aprobada,Fecha_aprobacion, Estado)
	VALUES (2333,12239,'Madrid','Viaje Proyecto','01/12/2013','02/12/2013',168.02,'España','05/12/2013',2314,'07/12/2013','Aprobada');

-- Usuario normal, 1 hoja cerrada, 1 creada (A departamento)
INSERT Hoja (Cod_emp,Referencia,Localidad,Motivo,Fecha_origen,Fecha_destino,Importe,Pais,Fecha_creada,Cod_aprobada,Fecha_aprobacion,Cod_autorizada,Fecha_autorizada, Estado)
	VALUES (2515,110,'Valencia','Viaje presentacion','12/02/2013','13/02/2013',515.9,'España','14/02/2013',2414,'20/02/2013',2414,'20/02/2013','Cerrada');
INSERT Hoja (Cod_emp,Referencia,Localidad,Motivo,Fecha_origen,Fecha_destino,Importe,Pais, Estado)
	VALUES (2515,110,'Valencia','Viaje Presentacion','01/12/2013','04/12/2013',174.8,'España','Creada');
INSERT Hoja (Cod_emp,Referencia,Localidad,Motivo,Fecha_origen,Fecha_destino,Importe,Pais,Fecha_creada, Estado)
	VALUES (2562,12239,'Madrid','Pronti','04/12/2013','05/12/2013',105,'España','07/12/2013','Abierta');
	
INSERT Hoja (Cod_emp,Referencia,Localidad,Motivo,Fecha_origen,Fecha_destino,Importe,Pais,Fecha_creada,Cod_aprobada,Fecha_aprobacion,Cod_autorizada,Fecha_autorizada, Estado)
	VALUES (2123,31111,'Madrid','Comida','12/05/2013','13/05/2013',20,'España','14/05/2013',2351,'20/05/2013',2665,'20/02/2013','Cerrada');	
	
-- Hoja caducada
INSERT Hoja (Cod_emp,Referencia,Localidad,Motivo,Fecha_origen,Fecha_destino,Importe,Pais,Fecha_creada,Cod_aprobada,Fecha_aprobacion, Estado,Motivo_rechazo)
	VALUES (2888,230,'Madrid','Viaje Proyecto','05/06/2013','07/06/2013',10,'España','08/06/2013',2314,'10/06/2013','Cancelada','Datos no justificados');
INSERT Hoja (Cod_emp,Referencia,Localidad,Motivo,Fecha_origen,Fecha_destino,Importe,Pais, Estado)
	VALUES (2888,230,'Mallorca','Viaje CAD','18/10/2013','1/11/2013',31,'España','Creada');

-- Hoja Cancelada

	
-- insertar en la tabla gasto
INSERT INTO GASTO VALUES (1000,'España','KM',20,0,8,'12/06/2013')
INSERT INTO GASTO VALUES (1000,'España','DIM',1,0,40.15,'13/06/2013')

INSERT INTO GASTO VALUES (1001,'España','KM',420,0,168,'01/08/2013')
INSERT INTO GASTO VALUES (1001,'España','DID',2,0,160.6,'02/08/2013')
INSERT INTO GASTO VALUES (1001,'España','HTL',0,125,125,'02/08/2013')

INSERT INTO GASTO VALUES (1002,'España','DCO',1,0,20,'11/07/2013')

INSERT INTO GASTO VALUES (1003,'España','DCO',1,0,20,'04/12/2013')
INSERT INTO GASTO VALUES (1003,'España','CAT',0,30.40,30.40,'05/12/2013')

INSERT INTO GASTO VALUES (1004,'Portugal','DID',1,0,80.30,'07/10/2013')
INSERT INTO GASTO VALUES (1004,'Portugal','HTL',0,80,80,'07/10/2013')	
INSERT INTO GASTO VALUES (1004,'España','GTP',0,28,28,'08/10/2013')

INSERT INTO GASTO VALUES (1005,'España','GTP',0,60,60,'12/10/2013')
INSERT INTO GASTO VALUES (1005,'Portugal','DCO',1,0,28,'12/10/2013')

INSERT INTO GASTO VALUES (1006,'España','GVA',0,23.40,23.40,'01/12/2013')
INSERT INTO GASTO VALUES (1006,'España','HTL',0,64.32,64.32,'02/12/2013')	
INSERT INTO GASTO VALUES (1006,'España','DIM',2,0,80.3,'03/12/2013')	

INSERT INTO GASTO VALUES (1007,'España','DID',3,0,240.9,'12/02/2013')	
INSERT INTO GASTO VALUES (1007,'España','HTL',0,240,240,'13/02/2013')
INSERT INTO GASTO VALUES (1007,'España','GTP',0,35,35,'14/02/2013')

INSERT INTO GASTO VALUES (1008,'España','DID',1,0,80.3,'02/12/2013')	
INSERT INTO GASTO VALUES (1008,'España','HTL',0,56.50,56.50,'03/12/2013')
INSERT INTO GASTO VALUES (1008,'España','GAP',0,38,38,'03/12/2013')

INSERT INTO GASTO VALUES (1009,'España','HTL',0,105,105,'04/12/2013')

INSERT INTO GASTO VALUES (1010,'España','C1P',0,20,20,'12/05/2013')

INSERT INTO GASTO VALUES (1011,'España','GVM',0,10,10,'07/06/2013')

INSERT INTO GASTO VALUES (1012,'España','GTP',0,31,31,'20/10/2013')
	
	
	
	
	
select cod_proyecto from Proyecto where Estado = 'Abierto' AND Cod_proyecto IN (select Cod_proyecto from EmpleadoProyecto where Cod_emp = 2333)

select cod_proyecto from Proyecto where Estado = 'Abierto' AND Cod_proyecto IN (select Cod_proyecto from EmpleadoProyecto where Cod_emp = 2333)


select id_hoja from HOJA where referencia =110 
select id_hoja from HOJA where referencia IN (select cod_proyecto from proyecto where cod_dep = 110)


select id_hoja from HOJA where referencia =110 or referencia IN (select cod_proyecto from proyecto where cod_dep = 110)

